@@ -29,26 +29,18 @@
 #include <libgnome/gnome-program.h>
 #include <libgnome/gnome-i18n.h>
 
-#include <libgnome/gnome-config.h>
-
-#include <libgnome/gnome-gconf.h>
-
-#include <libgnome/gnome-help.h>
-
-#include <libgnome/gnome-macros.h>
+#include <libgnome/gnome-exec.h>
 
 #include <libgnome/gnome-triggers.h>
 #include <libgnome/gnome-sound.h>
-
-#include <libgnome/gnome-score.h>
-
-#include <libgnome/gnome-exec.h>
-
 #include <libgnome/gnome-util.h>
 #include <libgnome/gnome-url.h>
 
+#include <libgnome/gnome-preferences.h>
 #include <libgnome/gnome-marshal.h>
 
+#include <libgnome/Gnome.h>
+
 #include <libgnome/gnome-init.h>
 
 #endif /* LIBGNOME_H */
